@@ -1,14 +1,13 @@
-import { contextSrv } from 'app/core/core';
+import { contextSrv } from 'app/core/services/context_srv';
 import { SavedQuery } from 'app/features/explore/QueryLibrary/types';
 
 export const canEditQuery = (query: SavedQuery) => {
   const userIsAuthor = query.user?.uid?.replace('user:', '') === contextSrv.user.uid;
   const userIsAdmin = contextSrv.hasRole('Admin');
-  const userIsViewer = contextSrv.hasRole('Viewer');
 
-  return (userIsAuthor && !userIsViewer) || userIsAdmin;
+  return (userIsAuthor && contextSrv.isEditor) || userIsAdmin;
 };
 
 export const canCreateQuery = () => {
-  return !contextSrv.hasRole('Viewer');
+  return contextSrv.isEditor;
 };
